html_inserts
open | /demo/html_inserts.html |
assertText | frame | KSS for a life.
click | insertAsFirstChild |
waitForText | frame | first: KSS for a life.
assertText | frame | first: KSS for a life.
click | insertAsLastChild |
waitForText | frame | first: KSS for a life.last:
assertText | frame | first: KSS for a life.last:
click | insert |
waitForText | frame | KSS for a life.
assertText | frame | KSS for a life.
type | text-to-insert | before 1
click | insertBefore |
waitForText | css=h4+div | KSS for a life. before 1
assertText | css=h4+div | KSS for a life. before 1
type | text-to-insert | after 1
click | insertAfter |
waitForText | css=#frame+div | KSS for a life. after 1
assertText | css=#frame+div | KSS for a life. after 1